@@ -1,12 +1,11 @@
-# -*- coding: utf-8 -*-
-
 """
 admin backend config
 """
 
+# Django
 from django.contrib import admin
 
-# Register your models here.
+# AA Time Zones
 from timezones.models import Timezones
 
 
@@ -55,9 +54,7 @@ class TimezonesAdmin(admin.ModelAdmin):
 
             notifications_count += 1
 
-        self.message_user(
-            request, "{} timezone(s) activated".format(notifications_count)
-        )
+        self.message_user(request, f"{notifications_count} timezone(s) activated")
 
     mark_as_active.short_description = "Activate selected timezone(s)"
 
@@ -76,8 +73,6 @@ class TimezonesAdmin(admin.ModelAdmin):
 
             notifications_count += 1
 
-        self.message_user(
-            request, "{} timezone(s) deactivated".format(notifications_count)
-        )
+        self.message_user(request, f"{notifications_count} timezone(s) deactivated")
 
     mark_as_inactive.short_description = "Deactivate selected timezone(s)"
