@@ -1,19 +1,20 @@
-# -*- coding: utf-8 -*-
-
 """
 hooks to AA
 """
 
+# Django
 from django.utils.translation import ugettext_lazy as _
 
-from timezones import urls, __title__
-
+# Alliance Auth
 from allianceauth import hooks
 from allianceauth.services.hooks import MenuItemHook, UrlHook
 
+# AA Time Zones
+from timezones import __title__, urls
+
 
 class AaTimezonesMenuItem(MenuItemHook):  # pylint: disable=too-few-public-methods
-    """ This class ensures only authorized users will see the menu entry """
+    """This class ensures only authorized users will see the menu entry"""
 
     def __init__(self):
         # setup menu entry for sidebar
